==> nextcloud-17.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/sv.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Laddar förhandsvisning...",
    "Saved" : "Sparat",
    "Admin" : "Admin",
    "a safe home for all your data" : "En säker lagringsplats för all din data",
    "Name cannot be empty" : "Namn kan inte vara tom",
    "The given name is too long" : "Det angivna namnet är för långt",
    "The given web address is too long" : "Den angivna adressen är för lång",
    "The given web address is not a valid URL" : "Den angivna webbadressen är inte en giltig URL",
    "The given legal notice address is too long" : "Den angivna juridiska notisadressen är för lång",
    "The given legal notice address is not a valid URL" : "Den angivna juridiska notisadressen är inte en giltig URL",
    "The given privacy policy address is too long" : "Den angivna sekretesspolicyadressen är för lång",
    "The given privacy policy address is not a valid URL" : "Den angivna sekretesspolicyadressen är inte en giltig URL",
    "The given slogan is too long" : "Den angivna slogan är för lång",
    "The given color is invalid" : "Den angivna färgen är inte tillgänglig",
    "The file was uploaded" : "Filen laddades upp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Uppladdningsfilen är för stor (upload_max_filesize i php.ini)",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uppladdade filen överstiger MAX_FILE_SIZE-instruktionen specificerad i HTML-form",
    "The file was only partially uploaded" : "Filen var endast delvis uppladdad",
    "No file was uploaded" : "Ingen fil laddades up",
    "Missing a temporary folder" : "Saknar en temporär mapp",
    "Could not write file to disk" : "Kunde inte skriva fil till disk",
    "A PHP extension stopped the file upload" : "Ett PHP-tillägg stoppade filuppladdning",
    "No file uploaded" : "Ingen fil uppladdad",
    "Unsupported image type" : "Filtypen är ej giltig",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Du använder redan ett anpassat tema. Dessa appinställningar kan skrivas över.",
    "Theming" : "Teman",
    "Legal notice" : "Rättsligt meddelande",
    "Privacy policy" : "Integritetspolicy",
    "Adjust the Nextcloud theme" : "Justera Nextcloud-tema",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teman gör det möjligt att enkelt skräddarsy utseendet på ditt moln. Detta kommer att synas för alla användare.",
    "Name" : "Namn",
    "Reset to default" : "Återställ till grundinställningar",
    "Web link" : "Webblänk",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Färg",
    "Logo" : "Logotyp",
    "Upload new logo" : "Ladda upp ny logotyp",
    "Login image" : "Inloggningsbild",
    "Upload new login background" : "Ladda upp ny bakgrundsbild",
    "Remove background image" : "Ta bort bakgrundsbild",
    "Advanced options" : "Avancerade inställningar",
    "Legal notice link" : "Länk rättsligt meddelande",
    "Privacy policy link" : "Länk integritetspolicy",
    "Header logo" : "Huvud-logga",
    "Upload new header logo" : "Ladda upp ny huvud-logga",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Ladda upp nya favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installera Imagemagick PHP-tillägget med stöd för SVG-bilder för att automatiskt generera favicons baserat på den uppladdade logotypen och färgen."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/sv.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Laddar förhandsvisning...",
    "Saved" : "Sparat",
    "Admin" : "Admin",
    "a safe home for all your data" : "ett säkert hem för alla dina data",
    "Name cannot be empty" : "Namn kan inte vara tom",
    "The given name is too long" : "Det angivna namnet är för långt",
    "The given web address is too long" : "Den angivna adressen är för lång",
    "The given web address is not a valid URL" : "Den angivna webbadressen är inte en giltig webbadress",
    "The given legal notice address is too long" : "Den angivna juridiska notisadressen är för lång",
    "The given legal notice address is not a valid URL" : "Den angivna juridiska notisadressen är inte en giltig webbadress",
    "The given privacy policy address is too long" : "Den angivna sekretesspolicyadressen är för lång",
    "The given privacy policy address is not a valid URL" : "Den angivna sekretesspolicyadressen är inte en giltig webbadress",
    "The given slogan is too long" : "Den angivna slogan är för lång",
    "The given color is invalid" : "Den angivna färgen är inte tillgänglig",
    "The file was uploaded" : "Filen laddades upp",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Uppladdningsfilen är för stor (upload_max_filesize i php.ini)",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uppladdade filen överstiger MAX_FILE_SIZE-instruktionen specificerad i HTML-form",
    "The file was only partially uploaded" : "Filen var endast delvis uppladdad",
    "No file was uploaded" : "Ingen fil laddades up",
    "Missing a temporary folder" : "Saknar en temporär mapp",
    "Could not write file to disk" : "Kunde inte skriva fil till disk",
    "A PHP extension stopped the file upload" : "Ett PHP-tillägg stoppade filuppladdning",
    "No file uploaded" : "Ingen fil uppladdad",
    "Unsupported image type" : "Filtypen är ej giltig",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Du använder redan ett anpassat tema. Dessa appinställningar kan skrivas över.",
    "Theming" : "Teman",
    "Legal notice" : "Rättsligt meddelande",
    "Privacy policy" : "Integritetspolicy",
    "Adjust the Nextcloud theme" : "Justera Nextcloud-tema",
    "Open documentation" : "Öppna dokumentationen",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Teman gör det möjligt att enkelt skräddarsy utseendet på ditt moln. Detta kommer att synas för alla användare.",
    "Name" : "Namn",
    "Reset to default" : "Återställ till grundinställningar",
    "Web link" : "Webblänk",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Färg",
    "Logo" : "Logotyp",
    "Upload new logo" : "Ladda upp ny logotyp",
    "Login image" : "Inloggningsbild",
    "Upload new login background" : "Ladda upp ny bakgrundsbild",
    "Remove background image" : "Ta bort bakgrundsbild",
    "Advanced options" : "Avancerade inställningar",
    "Legal notice link" : "Länk rättsligt meddelande",
    "Privacy policy link" : "Länk integritetspolicy",
    "Header logo" : "Huvud-logga",
    "Upload new header logo" : "Ladda upp ny huvud-logga",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Ladda upp nya favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installera Imagemagick PHP-tillägget med stöd för SVG-bilder för att automatiskt generera favicons baserat på den uppladdade logotypen och färgen."
},
"nplurals=2; plural=(n != 1);");
